NEResult<T> class

Available extensions

Constructors

NEResult({required int code, String? msg, T? data, String? requestId, int cost = 0})
const
NEResult.success()
const
NEResult.successWith(T? data)

Properties

code → int
final
cost → int
final
data → T?
final
hashCode → int
The hash code for this object.
no setterinherited
msg → String?
final
nonNullData → T
no setter
requestId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cast<U>() → NEResult<U>

Available on NEResult<void>, provided by the VoidResultExtension extension

isSuccess() → bool
map<U>(U mapper(T)) → NEResult<U>

Available on NEResult<T>, provided by the ObjectResultExtension extension

map<U>(U mapper()) → NEResult<U>

Available on NEResult<void>, provided by the VoidResultExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onFailure(void action(int, String?)) → NEResult<T>

Available on NEResult<T>, provided by the CommonResultExtension extension

onSuccess(void action(T)) → NEResult<T>

Available on NEResult<T>, provided by the ObjectResultExtension extension

onSuccess(void action()) → NEResult<void>

Available on NEResult<void>, provided by the VoidResultExtension extension

toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited