TextUtils class

Constructors

TextUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

regexDigital → RegExp
final
regexLetter → RegExp
final
regexLetterOrDigital → RegExp
final

Static Methods

isDigital(String? text) → bool
isEmpty(String? text) → bool
isLetter(String? text) → bool
isLetterOrDigital(String? text) → bool
isNotEmpty(String? text) → bool
nonEmptyEquals(String? text1, String? text2) → bool